pub struct MockLeasesApi {
LeasesApi_expectations: MockLeasesApi_LeasesApi,
}Fields
LeasesApi_expectations: MockLeasesApi_LeasesApiImplementations
Sourceimpl MockLeasesApi
impl MockLeasesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockLeasesApi
impl MockLeasesApi
Sourcepub fn expect_extend(&mut self) -> &mut Expectation
pub fn expect_extend(&mut self) -> &mut Expectation
Create an Expectation for mocking the extend method
Sourcepub fn expect_get_active(&mut self) -> &mut Expectation
pub fn expect_get_active(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_active method
Sourcepub fn expect_get_history(&mut self) -> &mut Expectation
pub fn expect_get_history(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_history method
Sourcepub fn expect_get_mine(&mut self) -> &mut Expectation
pub fn expect_get_mine(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_mine method
Sourcepub fn expect_revoke(&mut self) -> &mut Expectation
pub fn expect_revoke(&mut self) -> &mut Expectation
Create an Expectation for mocking the revoke method